# Uptrace for Python

[![Build Status](https://travis-ci.org/uptrace/uptrace-python.svg?branch=master)](https://travis-ci.org/uptrace/uptrace-python)
[![Documentation](https://img.shields.io/badge/docs-uptrace-brightgreen)](https://docs.uptrace.dev/python/)

<a href="https://docs.uptrace.dev/python/">
  <img src="https://docs.uptrace.dev/devicons/python-original.svg" height="200px" />
</a>

## Installation

```bash
pip install uptrace
```

## Introduction

uptrace-python is the official Uptrace client for Python that sends your traces/spans to
[Uptrace.dev](https://uptrace.dev) using OpenTelemetry.

See [uptrace-python documentation](https://docs.uptrace.dev/python/) for details.
